==> geolocation_leafletcenternode-1.0.0-alpha1.tar.gz: geolocation_leafletcenternode/src/Plugin/geolocation/MapFeature/LeafletCenterNode.php <==
<?php

namespace Drupal\geolocation_leafletcenternode\Plugin\geolocation\MapFeature;

use Drupal\geolocation\MapFeatureBase;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Template\Attribute;

/**
 * Provides Feature.
 *
 * @MapFeature(
 *   id = "leaflet_center_node",
 *   name = @Translation("Center Node"),
 *   description = @Translation("Center on current node location. Field Content:View node, URL as text required"),
 *   type = "leaflet",
 * )
 */
class LeafletCenterNode extends MapFeatureBase {

  /**
   * {@inheritdoc}
   */
  public static function getDefaultSettings() {
    return [
      'min_zoom' => FALSE,
      'reset_zoom' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getSettingsForm(array $settings, array $parents) {
    $form['min_zoom'] = [
      '#type' => 'number',
      '#min' => 0,
      '#step' => 1,
      '#title' => $this->t('Zoom level'),
      '#default_value' => $settings['min_zoom'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function alterMap(array $render_array, array $feature_settings, array $context = []) {
    if (empty($render_array['#children']['locations'])) {
      return $render_array;
    }

    if (!empty($context['view'])) {
      /** @var \Drupal\views\ViewExecutable $view */
      $view = $context['view'];
    }

    foreach ($render_array['#children']['locations'] as &$location) {
      $node_id = Drupal::token()->replace('{{ view_node }}', $context);

      if (empty($view)) {
        continue;
      }

      if (empty($location['#attributes'])) {
        $location['#attributes'] = [];
      }
      elseif (!is_array($location['#attributes'])) {
        $location['#attributes'] = new Attribute($location['#attributes']);
        $location['#attributes'] = $location['#attributes']->toArray();
      }

      if (isset($location['#attributes']['data-views-row-index'])) {
        $node_id = $view->getStyle()->tokenizeValue($node_id, (int) $location['#attributes']['data-views-row-index']);
        $location['#attributes']['data-nid'] = trim($node_id);
      }
    }

    $render_array = parent::alterMap($render_array, $feature_settings, $context);

    $render_array['#attached'] = BubbleableMetadata::mergeAttachments(
      empty($render_array['#attached']) ? [] : $render_array['#attached'],
      [
        'library' => [
          'geolocation_leafletcenternode/map_feature.' . $this->getPluginId(),
        ],
        'drupalSettings' => [
          'geolocation' => [
            'maps' => [
              $render_array['#id'] => [
                $this->getPluginId() => [
                  'enable' => TRUE,
                  'min_zoom' => $feature_settings['min_zoom'],
                ],
              ],
            ],
          ],
        ],
      ]
    );

    return $render_array;
  }

}

==> geolocation_leafletcenternode-1.1.0-alpha1.tar.gz: geolocation_leafletcenternode/src/Plugin/geolocation/MapFeature/LeafletCenterNode.php <==
<?php

namespace Drupal\geolocation_leafletcenternode\Plugin\geolocation\MapFeature;

use Drupal\geolocation\MapFeatureBase;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Template\Attribute;

/**
 * Provides Feature.
 *
 * @MapFeature(
 *   id = "leaflet_center_node",
 *   name = @Translation("Center Node"),
 *   description = @Translation("Center on current node location. Field Content:View node, URL as text required"),
 *   type = "leaflet",
 * )
 */
class LeafletCenterNode extends MapFeatureBase {

  /**
   * {@inheritdoc}
   */
  public static function getDefaultSettings() {
    return [
      'min_zoom' => FALSE,
      'reset_zoom' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getSettingsForm(array $settings, array $parents) {
    $form['min_zoom'] = [
      '#type' => 'number',
      '#min' => 0,
      '#step' => 1,
      '#title' => $this->t('Zoom level'),
      '#default_value' => $settings['min_zoom'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function alterMap(array $render_array, array $feature_settings, array $context = []) {
    if (empty($render_array['#children']['locations'])) {
      return $render_array;
    }

    if (!empty($context['view'])) {
      /** @var \Drupal\views\ViewExecutable $view */
      $view = $context['view'];
    }

    foreach ($render_array['#children']['locations'] as &$location) {
      $node_id = \Drupal::token()->replace('{{ view_node }}', $context);

      if (empty($view)) {
        continue;
      }

      if (empty($location['#attributes'])) {
        $location['#attributes'] = [];
      }
      elseif (!is_array($location['#attributes'])) {
        $location['#attributes'] = new Attribute($location['#attributes']);
        $location['#attributes'] = $location['#attributes']->toArray();
      }

      if (isset($location['#attributes']['data-views-row-index'])) {
        $node_id = $view->getStyle()->tokenizeValue($node_id, (int) $location['#attributes']['data-views-row-index']);
        $location['#attributes']['data-nid'] = trim($node_id);
      }
    }

    $render_array = parent::alterMap($render_array, $feature_settings, $context);

    $render_array['#attached'] = BubbleableMetadata::mergeAttachments(
      empty($render_array['#attached']) ? [] : $render_array['#attached'],
      [
        'library' => [
          'geolocation_leafletcenternode/map_feature.' . $this->getPluginId(),
        ],
        'drupalSettings' => [
          'geolocation' => [
            'maps' => [
              $render_array['#id'] => [
                $this->getPluginId() => [
                  'enable' => TRUE,
                  'min_zoom' => $feature_settings['min_zoom'],
                ],
              ],
            ],
          ],
        ],
      ]
    );

    return $render_array;
  }

}
